BraidHttpApiCallback

Enum BraidHttpApiCallback 

pub enum BraidHttpApiCallback {
    NewCamera(RegisterNewCamera),
    UpdateCurrentImage(PerCam<UpdateImage>),
    UpdateCamSettings(PerCam<UpdateCamSettings>),
    UpdateFeatureDetectSettings(PerCam<UpdateFeatureDetectSettings>),
    DoRecordCsvTables(bool),
    DoRecordMp4Files(bool),
    SetExperimentUuid(String),
    SetPostTriggerBufferSize(usize),
    PostTriggerMp4Recording,
    DoTakeNewBackgroundImage,
    SetBackgroundUpdating(bool),
    DoQuit,
}
API callback messages sent to Braid.

Variants



NewCamera(RegisterNewCamera)

Called from strand-cam to register a camera

Note this is different than the cam_info_handler which only queries for the appropriate camera configuration.



UpdateCurrentImage(PerCam<UpdateImage>)

Called from strand-cam to update the current image



UpdateCamSettings(PerCam<UpdateCamSettings>)

Called from strand-cam to update the current camera settings (e.g. exposure time)



UpdateFeatureDetectSettings(PerCam<UpdateFeatureDetectSettings>)

Called from strand-cam to update the current feature detection settings (e.g. threshold different)



DoRecordCsvTables(bool)

Start or stop recording data (.braid directory with csv tables for later .braidz file)



DoRecordMp4Files(bool)

Start or stop recording MKV videos for all cameras



SetExperimentUuid(String)

set uuid in the experiment_info table



SetPostTriggerBufferSize(usize)

Set the number of frames to buffer in each camera



PostTriggerMp4Recording

Initiate MKV recording using post trigger



DoTakeNewBackgroundImage

Take a new background image on all cameras.

Each camera re-initializes the background model used for feature detection from its currently incoming images.



SetBackgroundUpdating(bool)

Enable or disable continuous background model updating on all cameras.



DoQuit

Quit Braid.

This stops recording (closing all files), commands all connected cameras to quit, and then exits.