pub enum MiniArenaConfig {
NoMiniArena,
XYGrid(XYGridConfig),
}Expand description
Configuration defining potential mini arenas.
Variants
NoMiniArena
No mini arena is in use.
XYGrid(XYGridConfig)
A 2D grid arranged along the X and Y axes.
Implementations
Sourceimpl MiniArenaConfig
impl MiniArenaConfig
Sourcepub fn iter_locators(&self) -> impl Iterator<Item = MiniArenaLocator> + use<>
pub fn iter_locators(&self) -> impl Iterator<Item = MiniArenaLocator> + use<>
Iterate over all mini arena locators in this configuration.