StartCameraBackend

Enum StartCameraBackend 

pub enum StartCameraBackend {
    Remote,
    Pylon,
    Vimba,
    Webcam,
    Sim,
}
Camera backend selection for local camera startup.

Variants



Remote

Do not start a camera locally. Rather, wait for a remote camera to connect.



Pylon

Start a Pylon camera locally using the strand-cam program with the --camera-backend pylon argument.



Vimba

Start a Vimba camera locally using the strand-cam program with the --camera-backend vimba argument.



Webcam

Start a consumer webcam locally using the strand-cam program with the --camera-backend webcam argument.

Intended for development use. The camera name to use in the configuration is the human-readable device name of the webcam.



Sim

Start a simulated camera locally using the strand-cam program with the --camera-backend sim argument.

Used for end-to-end testing with no hardware: the camera renders synthetic images of simulated insects. The scenario is given by the STRAND_CAM_SIM_SPEC environment variable, and the camera name is one of the simulated camera names (e.g. simcam0).

Implementations

Source

impl StartCameraBackend

pub fn strand_cam_exe_name(&self) -> Option<&str>

Get the executable name for the camera backend.

All local backends are served by the single merged strand-cam executable, which selects the backend at runtime via Self::camera_backend_arg.

pub fn camera_backend_arg(&self) -> Option<&'static str>

Get the value for the --camera-backend argument of the strand-cam executable, or None for a remote camera (whose backend is chosen on the remote machine).