pub enum TriggerType {
TriggerboxV1(TriggerboxConfig),
PtpSync(PtpSyncConfig),
DeviceTimestamp,
FakeSync(FakeSyncConfig),
}Expand description
Camera synchronization method configuration.
Variants
TriggerboxV1(TriggerboxConfig)
Cameras are synchronized via hardware triggers controlled via a Straw Lab triggerbox.
PtpSync(PtpSyncConfig)
Cameras are synchronized using PTP (Precision Time Protocol, IEEE 1588).
DeviceTimestamp
Cameras are synchronized using device timestamps.
FakeSync(FakeSyncConfig)
Cameras are not synchronized, but we pretend they are.