BraidCameraConfig

Struct BraidCameraConfig 

pub struct BraidCameraConfig {
    pub name: String,
    pub camera_settings_filename: Option<PathBuf>,
    pub pixel_format: Option<String>,
    pub point_detection_config: ImPtDetectCfg,
    pub start_backend: StartCameraBackend,
    pub acquisition_duration_allowed_imprecision_msec: Option<f64>,
    pub http_server_addr: Option<String>,
    pub send_current_image_interval_msec: u64,
    /* private fields */
}
Configuration for a single camera in the Braid system.

Fields

name: String

The name of the camera (e.g. “Basler-22005677”)

(This is the original UTF-8 camera name, not the ROS-encoded camera name in which certain characters are not allowed.)

camera_settings_filename: Option<PathBuf>

Filename of vendor-specific camera settings file.

Can contain shell variables such as ~, $A, or ${B}.

pixel_format: Option<String>

The pixel format to use.

point_detection_config: ImPtDetectCfg

Configuration for detecting points.

start_backend: StartCameraBackend

Which camera backend to use.

acquisition_duration_allowed_imprecision_msec: Option<f64>

Allowed imprecision for frame acquisition duration.

http_server_addr: Option<String>

The SocketAddr on which the strand camera BUI server should run.

send_current_image_interval_msec: u64

The interval at which the current image should be sent, in milliseconds.

Implementations

Source

impl BraidCameraConfig

pub fn default_absdiff_config(name: String) -> Self

Create a default camera configuration with absolute difference point detection.