BraidHttpApiSharedState

Struct BraidHttpApiSharedState 

pub struct BraidHttpApiSharedState {
Show 14 fields pub trigger_type: TriggerType, pub needs_clock_model: bool, pub clock_model: Option<ClockModel>, pub csv_tables_dirname: Option<RecordingPath>, pub fake_mp4_recording_path: Option<RecordingPath>, pub post_trigger_buffer_size: usize, pub calibration_filename: Option<String>, pub connected_cameras: Vec<CamInfo>, pub background_model_updating: BTreeMap<RawCamName, bool>, pub camera_image_dimensions: BTreeMap<RawCamName, (u32, u32)>, pub model_server_addr: Option<SocketAddr>, pub flydra_app_name: String, pub all_expected_cameras_are_synced: bool, pub version_update: Option<VersionUpdate>,
}
Shared state for the Braid HTTP API.

Fields

trigger_type: TriggerType

Camera synchronization trigger configuration.

needs_clock_model: bool

Whether a clock model is needed for synchronization.

clock_model: Option<ClockModel>

The current clock model for time synchronization.

csv_tables_dirname: Option<RecordingPath>

Directory path for CSV table recordings.

fake_mp4_recording_path: Option<RecordingPath>

Path for MP4 recording (signals if cameras are recording).

post_trigger_buffer_size: usize

Size of post-trigger buffer in frames.

calibration_filename: Option<String>

Filename of camera calibration file.

connected_cameras: Vec<CamInfo>

List of connected camera information.

background_model_updating: BTreeMap<RawCamName, bool>

Whether the feature detection background model is continuously updating, per camera.

Cameras whose feature detection settings have not (yet) been received are absent from this map.

camera_image_dimensions: BTreeMap<RawCamName, (u32, u32)>

Image dimensions as (width, height) in pixels, per camera.

Cameras whose image has not (yet) been received are absent from this map.

model_server_addr: Option<SocketAddr>

Address of the model server.

flydra_app_name: String

Name of the Flydra application.

all_expected_cameras_are_synced: bool

Whether all expected cameras are synchronized.

version_update: Option<VersionUpdate>

A newer available release discovered by the background version check, or None if up to date (or the check has not yet found a newer version).