pub struct Data2dDistortedRowF32 {Show 15 fields
pub camn: CamNum,
pub frame: i64,
pub timestamp: Option<FlydraFloatTimestampLocal<Triggerbox>>,
pub cam_received_timestamp: FlydraFloatTimestampLocal<HostClock>,
pub device_timestamp: Option<u64>,
pub block_id: Option<u64>,
pub x: f32,
pub y: f32,
pub area: f32,
pub slope: f32,
pub eccentricity: f32,
pub frame_pt_idx: u8,
pub cur_val: u8,
pub mean_val: f32,
pub sumsqf_val: f32,
}Expand description
Lower precision version of Data2dDistortedRow for saving to disk.
Fields
camn: CamNumThe number of the camera.
frame: i64The synchronized frame number.
This is very likely to be different than Self::block_id, the camera’s internal frame number, because Braid synchronizes the frames so that, e.g. “frame 10” occurred at the same instant across all cameras.
timestamp: Option<FlydraFloatTimestampLocal<Triggerbox>>This is the trigger timestamp (if available).
cam_received_timestamp: FlydraFloatTimestampLocal<HostClock>Timestamp when the camera received the frame.
device_timestamp: Option<u64>timestamp from the camera
block_id: Option<u64>Frame number from the camera.
Note that this is not the synchronized frame number, which is Self::frame.
x: f32The X (horizontal) coordinate of the detection, in camera pixels.
y: f32The Y (vertial) coordinate of the detection, in camera pixels.
area: f32The area of the detection, in camera pixels^2.
slope: f32The slope of the detection.
The orientation, modulo 𝜋, of the detection, is atan(slope).
eccentricity: f32The eccentricity of the detection.
frame_pt_idx: u8The index of this particular detection within a given frame.
Multiple detections can occur within a single frame, and each succesive detection will have a higher index.
cur_val: u8Current pixel value.
mean_val: f32Mean pixel value.
sumsqf_val: f32Sum of squares of pixel values.