KalmanEstimatesRow

Struct KalmanEstimatesRow 

pub struct KalmanEstimatesRow {
Show 18 fields pub obj_id: u32, pub frame: SyncFno, pub timestamp: Option<FlydraFloatTimestampLocal<Triggerbox>>, pub x: f64, pub y: f64, pub z: f64, pub xvel: f64, pub yvel: f64, pub zvel: f64, pub P00: f64, pub P01: f64, pub P02: f64, pub P11: f64, pub P12: f64, pub P22: f64, pub P33: f64, pub P44: f64, pub P55: f64,
}
Kalman filter state estimate record for CSV output.

Fields

obj_id: u32

Object ID being tracked.

frame: SyncFno

Synchronized frame number.

timestamp: Option<FlydraFloatTimestampLocal<Triggerbox>>

The timestamp when the trigger pulse fired.

Note that calculating this live in braid requires that the clock model has established itself. Thus, the initial frames immediately after synchronization will not have a timestamp.

x: f64

X position estimate in meters.

y: f64

Y position estimate in meters.

z: f64

Z position estimate in meters.

xvel: f64

X velocity estimate in meters per second.

yvel: f64

Y velocity estimate in meters per second.

zvel: f64

Z velocity estimate in meters per second.

P00: f64

Covariance matrix element P[0,0].

P01: f64

Covariance matrix element P[0,1].

P02: f64

Covariance matrix element P[0,2].

P11: f64

Covariance matrix element P[1,1].

P12: f64

Covariance matrix element P[1,2].

P22: f64

Covariance matrix element P[2,2].

P33: f64

Covariance matrix element P[3,3].

P44: f64

Covariance matrix element P[4,4].

P55: f64

Covariance matrix element P[5,5].