pub struct RegisterNewCamera {
pub raw_cam_name: RawCamName,
pub http_camserver_info: Option<BuiServerInfo>,
pub cam_settings_data: Option<UpdateCamSettings>,
pub current_image_png: PngImageData,
pub camera_periodic_signal_period_usec: Option<f64>,
}Expand description
Camera registration message sent to Braid.
Fields
raw_cam_name: RawCamNameThe name of the camera as returned by the camera
http_camserver_info: Option<BuiServerInfo>Location of the camera control HTTP server.
cam_settings_data: Option<UpdateCamSettings>The camera settings.
current_image_png: PngImageDataThe current image.
camera_periodic_signal_period_usec: Option<f64>The period of the periodic signal generator in the camera. This is used for PTP-based synchronization.